import requests
import json
from common.version_helpers import get_split_version

def get_last_release(sentry_token, project_name):
    url = "https://sentry.evosoft.xyz/api/0/organizations/evosoft/releases/"

    headers = {
      'Authorization': 'Bearer {}'.format(sentry_token)
    }

    response = requests.get(url, headers=headers)

    print('status_code:', response.status_code)

    releases = list(response.json())
    releases.sort(reverse=True, key=lambda key: int(key['id']))

    for release in releases:
        for project in release['projects']:
            if project['slug'] == project_name:
                print("last_version:", release['version'])
                if release['lastCommit']:
                    print("last_commit_id:", release['lastCommit']['id'])
                    return ( get_split_version(release['version']), release['lastCommit']['id'])
                else:
                    return ( get_split_version(release['version']), "")

    return ( get_split_version("0.1.0"), "" )

def create_release(sentry_token, project_name, version, commits):
    url = "https://sentry.evosoft.xyz/api/0/organizations/evosoft/releases/"

    payload = json.dumps({
        "version": version,
        "commits": commits,
        "projects": [ project_name ]
    })

    headers = {
      'Authorization': 'Bearer {}'.format(sentry_token),
      'Content-Type': 'application/json'
    }

    resp = requests.post(url, headers=headers, data=payload)

    print(resp.text)
